# User guide
You can use pyTESEO to generate TESEO simulation's files, obtain configuration variables, plot default figures of the results and export results to standard formats.

---

## Create domain files
TESEO model uses a grid of the computational domain where the depth of the water cells are defined as positive values. As default land values are defined as -999. To write this file you can use the function {py:func}`pyteseo.io.write_grid`. Also you can use the function {py:func}`pyteseo.io.read_grid` to read this file and load it into a pandas DataFrame.

TESEO domain files can be ploted using {py:func}`pyteseo.plot.plot_grid` and {py:func}`pyteseo.plot.plot_coastline`.

---

## Create forcing files
```{warning}
To be completed!
```

---

## Get forcing configuration variables
```{warning}
To be completed!
```

---

## Create configuration files
```{warning}
To be completed!
```

---

## Export reults to standard formats
```{warning}
To be completed!
```
